@@ -6,5 +6,5 @@ SqlCarve Module
 Ce module est la sclasse d'initialisation de la librairie
 """
 
-from src.sqlcarve.validator.validator import *
-from src.sqlcarve.main import analyse
\ No newline at end of file
+from sqlcarve.validator.validator import *
+from sqlcarve.main import analyse
\ No newline at end of file
